==> karlender-v0.6.0.tar.gz: karlender-v0.6.0/src/pages/week.rs <==
use crate::store::{gstore::*, store, State};
use crate::widgets::WeekGrid;
use crate::widgets::{InfinityCarousel, MonthGrid};
use gettextrs::gettext;
use gtk::prelude::*;
use gtk_rust_app::widgets::Page;

pub const WEEK_PAGE_NAME: &str = "week";

#[widget(@store extends gtk::Box)]
#[template(file = "week.ui")]
struct WeekPage {
    #[selector(state.ui.week_delta)]
    select_current_week: (),
}

impl WeekPage {
    pub fn new() -> Self {
        glib::Object::new(&[]).expect("Failed to create month page")
    }

    pub fn constructed(&self) {
        let carousel = InfinityCarousel::new(|i| {
            let mg = WeekGrid::new(i);
            mg.upcast()
        });

        carousel.show_nav_buttons(false);

        self.connect_realize(|s| s.realized());

        self.append(&carousel);
    }

    fn realized(&self) {
        self.carousel().connect_page_changed(|ic| {
            let page: WeekGrid = ic.current_page();
            let title = page.title();
            dispatch!(
                crate::store::_NAVIGATE_WITH_TITLE,
                (WEEK_PAGE_NAME.to_string(), title)
            );
        });
    }

    fn select_current_week(&self, state: &State) {
        self.carousel().set_current(state.ui.week_delta);
    }

    fn carousel(&self) -> InfinityCarousel {
        self.first_child().unwrap().downcast().unwrap()
    }

    pub fn weekly_title(&self) -> String {
        let c: InfinityCarousel = self.first_child().unwrap().downcast().unwrap();
        let mg: MonthGrid = c.current_page();
        mg.title()
    }
}

impl Page for WeekPage {
    fn name(&self) -> &'static str {
        WEEK_PAGE_NAME
    }

    fn title_and_icon(&self) -> Option<(String, String)> {
        Some((gettext("Week"), "week-symbolic".into()))
    }
}

impl Default for WeekPage {
    fn default() -> Self {
        Self::new()
    }
}

==> karlender-v0.9.1.tar.gz: karlender-v0.9.1/src/pages/week.rs <==
use crate::store::{gstore::*, store, State};
use crate::widgets::InfinityCarousel;
use crate::widgets::WeekGrid;
use gettextrs::gettext;
use gtk::prelude::*;
use gtk_rust_app::widgets::Page;

pub const WEEK_PAGE_NAME: &str = "week";

#[widget(@store extends gtk::Box)]
#[template(file = "week.ui")]
struct WeekPage {
    #[selector(state.ui.week_delta)]
    select_current_week: (),
}

impl WeekPage {
    pub fn new() -> Self {
        glib::Object::new(&[]).expect("Failed to create month page")
    }

    pub fn constructed(&self) {
        let carousel = InfinityCarousel::new(|i| {
            let mg = WeekGrid::new(i);
            mg.upcast()
        });

        carousel.show_nav_buttons(false);

        self.connect_realize(|s| s.realized());

        self.append(&carousel);
    }

    fn realized(&self) {
        self.carousel().connect_page_changed(|ic| {
            if let Some(page) = ic.current_page::<WeekGrid>() {
                let title = page.title();
                dispatch!(
                    crate::store::_NAVIGATE_WITH_TITLE,
                    (WEEK_PAGE_NAME.to_string(), title)
                );
            }
        });
    }

    fn select_current_week(&self, state: &State) {
        self.carousel().set_current(state.ui.week_delta);
    }

    fn carousel(&self) -> InfinityCarousel {
        self.first_child().unwrap().downcast().unwrap()
    }

    pub fn title(&self) -> String {
        let c: InfinityCarousel = self.first_child().unwrap().downcast().unwrap();
        if let Some(mg) = c.current_page::<WeekGrid>() {
            mg.title()
        } else {
            "Calendar".into()
        }
    }
}

impl Page for WeekPage {
    fn name(&self) -> &'static str {
        WEEK_PAGE_NAME
    }

    fn title_and_icon(&self) -> Option<(String, String)> {
        Some((gettext("Week"), "week-symbolic".into()))
    }
}

impl Default for WeekPage {
    fn default() -> Self {
        Self::new()
    }
}
